///////////////////////////////////////////////////////////////////////////////
//
// TRIPjxp Programming Examples
//
// Copyright (C) 2011 Tieto Sweden AB - All Rights Reserved
//
///////////////////////////////////////////////////////////////////////////////
//
// Modification History:
//		TF	Dec 29, 2011	Created
//
///////////////////////////////////////////////////////////////////////////////

package com.tietoenator.trip.jxp.examples.control;

import com.tietoenator.trip.jxp.TdbException;
import com.tietoenator.trip.jxp.TdbControlObject;
import com.tietoenator.trip.jxp.control.TdbClassificationSchemesList;
import com.tietoenator.trip.jxp.control.TdbControlObjectList;
import com.tietoenator.trip.jxp.control.TdbDatabaseAccessList;
import com.tietoenator.trip.jxp.control.TdbDatabaseFieldList;
import com.tietoenator.trip.jxp.control.TdbDatabaseList;
import com.tietoenator.trip.jxp.control.TdbEntryFormList;
import com.tietoenator.trip.jxp.control.TdbFileManagerList;
import com.tietoenator.trip.jxp.control.TdbGroupAccessList;
import com.tietoenator.trip.jxp.control.TdbGroupList;
import com.tietoenator.trip.jxp.control.TdbGroupMemberList;
import com.tietoenator.trip.jxp.control.TdbManagerList;
import com.tietoenator.trip.jxp.control.TdbOutputFormatList;
import com.tietoenator.trip.jxp.control.TdbOwnedDatabaseList;
import com.tietoenator.trip.jxp.control.TdbProcedureList;
import com.tietoenator.trip.jxp.control.TdbPublicAccessList;
import com.tietoenator.trip.jxp.control.TdbSearchFormList;
import com.tietoenator.trip.jxp.control.TdbUserAccessList;
import com.tietoenator.trip.jxp.control.TdbUserList;
import com.tietoenator.trip.jxp.control.TdbUserManagerList;
import com.tietoenator.trip.jxp.examples.util.Console;
import com.tietoenator.trip.jxp.examples.util.SessionFactory;
import com.tietoenator.trip.jxp.session.TdbSession;

/**
 * Shows how to check for membership in TdbControlObjectList.
 */
public class ListCheckMember
{
    private TdbSession m_session;
    private int        m_listtype;
    private String     m_db;
    private String     m_group;
    private String     m_user;
    private String     m_item;
    
    ListCheckMember()
            throws TdbException
    {
        // Create a session on a physical server (no grid support)
        m_session = SessionFactory.newInstance("**** Control Object List Membership Check ****", false);
        m_listtype = 0;
        m_db = null;
        m_group = null;
        m_user = null;
        m_item = null;
    }

    public void close()
    {
        try
        {
            if (null != m_session)
                m_session.logout();
        }
        catch (Exception ignore) {}
        m_session = null;
    }

   boolean arrayContains(int val, int[] arr)
   {
       for (int item : arr)
       {
           if (val == item)
               return true;
       }
       return false;
   }

    void setParameters() throws TdbException
    {
        Console stdin = new Console();

        System.out.println("Select a list type:");
        System.out.println("  1. Classification Schemes");
        System.out.println("  2. Database Access");
        System.out.println("  3. Database Fields");
        System.out.println("  4. Databases");
        System.out.println("  5. Entry Forms");
        System.out.println("  6. File Managers");
        System.out.println("  7. Group Access");
        System.out.println("  8. All Known Groups");
        System.out.println("  9. Group Members");
        System.out.println(" 10. Managers");
        System.out.println(" 11. Output Formats");
        System.out.println(" 12. Owned Databases");
        System.out.println(" 13. Procedures");
        System.out.println(" 14. Databases with Public Access");
        System.out.println(" 15. Search Forms");
        System.out.println(" 16. User Access");
        System.out.println(" 17. All Known Users");
        System.out.println(" 18. User Managers");
        System.out.println(" 19. Groups to which a specified user belongs");
        System.out.println();

        while (m_listtype<1 || m_listtype>19)
        {
            m_listtype = stdin.readint("List type ( 1 - 19 )",0,true);
            if (m_listtype<1 || m_listtype>19)
                System.out.println("INVALID TYPE! Please specify a value in the range 1 - 19.");
        }

    if (arrayContains(m_listtype,new int[]{2,3,5,11}))
        {
            m_db = null;
            while (m_db == null)
                m_db = stdin.readln("Database", null);
        }

        if (arrayContains(m_listtype,new int[]{16,19}))
        {
            m_user = null;
            while (m_user == null)
                m_user = stdin.readln("User name", null);
        }

        if (arrayContains(m_listtype,new int[]{7,9}))
        {
            m_group = null;
            while (m_group == null)
                m_group = stdin.readln("Group name", null);
        }

        if (arrayContains(m_listtype,new int[]{13}))
        {
            m_user = null;
            while (m_user == null)
                m_user = stdin.readln("User or group name", null);
            m_group = m_user;
        }

        m_item = null;
        while (m_item == null)
            m_item = stdin.readln("Name of list member to check for",null);

        System.out.println();
    }

   void process() throws TdbException
   {
        TdbControlObjectList list = null;
        switch (m_listtype)
        {
            case 1:
                list = new TdbClassificationSchemesList(m_session);
                break;
            case 2:
                list = new TdbDatabaseAccessList(m_session, m_db);
                break;
            case 3:
                list = new TdbDatabaseFieldList(m_session, m_db);
                break;
            case 4:
                list = new TdbDatabaseList(m_session);
                break;
            case 5:
                list = new TdbEntryFormList(m_session, m_db);
                break;
            case 6:
                list = new TdbFileManagerList(m_session, true);
                break;
            case 7:
                list = new TdbGroupAccessList(m_session, m_group);
                break;
            case 8:
                list = new TdbGroupList(m_session);
                break;
            case 9:
                list = new TdbGroupMemberList(m_session, m_group);
                break;
            case 10:
                list = new TdbManagerList(m_session, true);
                break;
            case 11:
                list = new TdbOutputFormatList(m_session, m_db);
                break;
            case 12:
                list = new TdbOwnedDatabaseList(m_session);
                break;
            case 13:
                list = new TdbProcedureList(m_session, m_group);
                break;
            case 14:
                list = new TdbPublicAccessList(m_session);
                break;
            case 15:
                list = new TdbSearchFormList(m_session);
                break;
            case 16:
                list = new TdbUserAccessList(m_session, m_user);
                break;
            case 17:
                list = new TdbUserList(m_session, true, true);
                break;
            case 18:
                list = new TdbUserManagerList(m_session, true);
                break;
            case 19:
                list = new TdbGroupList(m_session, m_user, true, true);
                break;
            default:
                break;
        }

        System.out.println("List contains "+Integer.toString(list.size())+" elements.");
        System.out.print("Your specified item \""+m_item+"\" was ");
        if (!list.contains(m_item))
            System.out.print("not ");
        System.out.println("found in the list.");

        if (list.size() > 0)
        {
            Console stdin = new Console();
            System.out.println();
            if (stdin.readint("Show list (0=no, 1=yes)?",0,true) != 0)
            {
                System.out.println();
                for (TdbControlObject obj : list)
                {
                    System.out.print("   ");
                    System.out.print(obj.getObjectType().toString());
                    System.out.print(" ");
                    System.out.println(obj.getName());
                }
            }
        }
   }

    /**
     * Based on session type, print a list of available databases or grid clusters
     * @param args Not used
     */
    public static void main(String[] args)
    {
        ListCheckMember app = null;
        try
        {
            app = new ListCheckMember();
            app.setParameters();
            app.process();
        }
        catch (TdbException e)
        {
            System.out.println(e.getDebugMessage());
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }
        finally
        {
            if (null != app)
                app.close();
        }
    }

}
