///////////////////////////////////////////////////////////////////////////////
//
// TRIPjxp Programming Examples
//
// Copyright (C) 2006-2009 Tieto Sweden AB - All Rights Reserved
//
///////////////////////////////////////////////////////////////////////////////
//
// Modification History:
//		GF	Jul 31, 2006	Created
//
///////////////////////////////////////////////////////////////////////////////
package com.tietoenator.trip.jxp.examples.data;

import com.tietoenator.trip.jxp.*;
import com.tietoenator.trip.jxp.data.*;
import com.tietoenator.trip.jxp.logging.*;
import com.tietoenator.trip.jxp.examples.util.Console;
import com.tietoenator.trip.jxp.examples.util.SessionFactory;
import com.tietoenator.trip.jxp.session.TdbSession;

/**
 * This class demonstrates how to interact with TRIPviewfunctionality, i.e.
 * extracting text from binary files, and rendering a binary object into one
 * or more formats for viewing.
 *
 * See the class View2 for an example of how to interact with TRIPview-C and 
 * TRIPview 2.x.
 */
public class View
{

   private TdbSession m_session;

   /**
    * Constructor
    * @throws TdbException
    */
   public View()
           throws TdbException
   {
      // Create a session on a physical server (no grid support)
      m_session = SessionFactory.newInstance("**** TRIPview example ****", false);
      m_session.setActivityLog(new TdbConsoleLogger(true));
   }

   /**
    * Perform text extraction or HTML conversion as specified.
    */
   public void process(String dbname, String strfield, String txtfield)
           throws Exception
   {
      boolean brk = false;
      while (!brk)
      {
         TdbRecord rec = new TdbRecord(m_session);
         rec.setDatabaseName(dbname);

         // Prompt the user to store or retrieve a record
         Console stdin = new Console();
         int mode = stdin.readint("Mode (0 = store, 1 = retrieve)", 0, true);
         switch (mode)
         {
         case 0:
         {
            String name = null;
            while (name == null)
            {
               name = stdin.readln("File name", null);
            }
            TdbStringField fld = (TdbStringField) rec.getHead().createField(strfield, TdbFieldType.StringField);
            fld.copyFromFile(name);
            fld.setExtractionTarget(txtfield);
            rec.commit();
            break;
         }

         case 1:
         {
            int recnr = stdin.readint("Record #", 1, true);
            int rend = stdin.readint("Rendition (0-none, 1-HTML, 2-MHT)", 0, true);

            // Request the appropriate rendition (or none)
            TdbFieldTemplate fld = null;
            switch (rend)
            {
            case 0:
               fld = new TdbFieldTemplate(strfield);
               break;
            case 1:
               fld = new TdbRendition(strfield, TdbRenditionType.BasicHTML);
               break;
            case 2:
               fld = new TdbRendition(strfield, TdbRenditionType.MimeEncodedHtml);
               break;
            default:
               brk = true;
            }

            if (!brk)
            {
               rec.setRecordId(recnr);
               rec.addToTemplate(fld);
               rec.get();

               String name = null;
               while (name == null)
               {
                  name = stdin.readln("File name", null);
               }
               TdbStringField str = (TdbStringField) rec.getHead().getField(strfield);
               str.copyToFile(name);
            }
            break;
         }

         default:
            brk = true;
         }

      }
      // Terminate the session
      m_session.logout();
   }

   /**
    * Main entry point
    * @param args Not used
    */
   public static void main(String[] args)
   {
      try
      {
         View vw = new View();

         Console stdin = new Console();
         String db = null, str = null, txt = null;

         // Get a valid database name, and set the list of
         // retrieval fields from it
         while (db == null)
         {
            db = stdin.readln("Database", null);
         }
         while (str == null)
         {
            str = stdin.readln("String field", null);
         }
         while (txt == null)
         {
            txt = stdin.readln("Text field", null);
         }


         // Perform the retrieval
         vw.process(db, str, txt);
      }
      catch (TdbException e)
      {
         System.out.println(e.getDebugMessage());
      }
      catch (Exception e)
      {
         e.printStackTrace();
      }
   }
}
